==> ginkgocadx_2.5.1.0.orig.tar.gz: ginkgocadx-2.5.1.0/src/cadxcore/main/gui/paneltags/paneltags.cpp <==
/*
 *  
 *  $Id: paneltags.cpp 3834 2011-05-10 07:42:57Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#include <api/globals.h>

#include "paneltags.h"

#include <api/icontroladoreventos.h>

#include <api/icontextoestudio.h>
#include <api/dicom/idicommanager.h>

#include <main/controllers/pacscontroller.h>
#include <main/controllers/controladorvistas.h>

#include <eventos/eventosginkgo.h>


GNC::GUI::PanelTags::PanelTags(wxWindow* pPadre) : PanelTagsBase(pPadre, -1, wxDefaultPosition, wxDefaultSize)
{
	Freeze();
	//eventos
//	m_pTags->Connect(wxEVT_PG_CHANGED,wxPropertyGridEventHandler(PanelTags::OnPropertyChanged),NULL,this);
//	m_pTags->Connect(wxEVT_PG_CHANGING,wxPropertyGridEventHandler(PanelTags::OnPropertyChanging),NULL,this);

	Thaw();
}

GNC::GUI::PanelTags::~PanelTags()
{
//	m_pTags->Disconnect(wxEVT_PG_CHANGED,wxPropertyGridEventHandler(PanelTags::OnPropertyChanged),NULL,this);
//	m_pTags->Disconnect(wxEVT_PG_CHANGING,wxPropertyGridEventHandler(PanelTags::OnPropertyChanging),NULL,this);
}

bool GNC::GUI::PanelTags::IsVisiblePanelTags()
{
	return IsShown();
}

void GNC::GUI::PanelTags::MostrarOcultarPanelTags()
{
	if (IsShown()) {
		GNC::GCS::ControladorVistas::Instance()->OcultarPanel(this);
	} else {
		GNC::GCS::ControladorVistas::Instance()->MostrarPanel(this);
	}
}

void GNC::GUI::PanelTags::SetEstudio(GnkPtr<GNC::GCS::IContextoEstudio> pEstudio)
{
	m_pTags->Clear();
	if(!pEstudio.IsValid())
	{
		
		return;
	}

	GnkPtr<GIL::DICOM::TipoMetaInfo> info = pEstudio->GetMetaInfoDeImagenActiva();
	GnkPtr<GIL::DICOM::TipoJerarquia> pJerarquia = pEstudio->GetTagsImagenDeImagenActiva();
	
	GIL::DICOM::IDICOMManager*	pDICOMManager = GIL::DICOM::PACSController::Instance()->CrearInstanciaDeDICOMManager();
	
	if (info) {
		for(GIL::DICOM::TipoMetaInfo::ListaTags::iterator it = info->tags.begin(); it!= info->tags.end(); it++) {
			wxString helpString = wxString::FromUTF8(pDICOMManager->GetDescription((*it).first).c_str());
			
			wxStringProperty* prop = NULL;
			wxString valor;
			if((*it).second.size()>100) {
				valor = _("Data");
			} else {
				std::string oidname = pDICOMManager->GetOIDName((*it).second);
				if (oidname.size() > 0) {
					valor = wxString::FromUTF8(oidname.c_str()) + wxT("[") + wxString::FromUTF8((*it).second.c_str()) + wxT("]");
				}
				else {
					valor = wxString::FromUTF8((*it).second.c_str());
				}
			}
			
			wxString label;
			if(helpString.size()>0){
				label = wxT("(") + wxString::FromUTF8((*it).first.c_str()) + wxT(") ") + helpString;
			}else{
				label = wxT("(") + wxString::FromUTF8((*it).first.c_str()) + wxT(") ");
			}
			while(m_pTags->GetProperty(label) != NULL)
				label = label + wxT(" ");
			prop = new wxStringProperty(label,
										wxPG_LABEL,valor);
			
			prop->SetHelpString(wxString::FromUTF8((*it).first.c_str()));
			m_pTags->AppendIn(m_pTags->GetRoot(), prop);
			prop->SetFlag(wxPG_PROP_READONLY);
			//m_pTags->SetDisableProperty(prop);
		}
	}
	
	SetTags(*pJerarquia, m_pTags->GetRoot(), pDICOMManager);
	GIL::DICOM::PACSController::Instance()->LiberarInstanciaDeDICOMManager(pDICOMManager);
}

void GNC::GUI::PanelTags::SetTags(GIL::DICOM::TipoJerarquia& base, wxPGPropArg idPadre, GIL::DICOM::IDICOMManager* pDICOMManager) 
{	
	for(GIL::DICOM::ListaTags::iterator it = base.tags.begin(); it!= base.tags.end(); it++) {
		wxString helpString = wxString::FromUTF8(pDICOMManager->GetDescription((*it).first).c_str());
		wxStringProperty* prop = NULL;
		wxString valor;
		if((*it).second.size()>100) {
			valor = _("Data");
		} else {
			valor = wxString::FromUTF8((*it).second.c_str());
		}

		wxString label;
		if(helpString.size()>0){
			label = wxT("(") + wxString::FromUTF8((*it).first.c_str()) + wxT(") ") + helpString;
		}else{
			label = wxT("(") + wxString::FromUTF8((*it).first.c_str()) + wxT(") ");
		}
		while(m_pTags->GetProperty(label) != NULL)
			label = label + wxT(" ");
		prop = new wxStringProperty(label,
			wxPG_LABEL,valor);

		prop->SetHelpString(wxString::FromUTF8((*it).first.c_str()));
		m_pTags->AppendIn(idPadre, prop);
		prop->SetFlag(wxPG_PROP_READONLY);
		//m_pTags->SetDisableProperty(prop);
	}

	for(GIL::DICOM::TipoJerarquia::ListaJerarquias::iterator it = base.secuencias.begin(); it!=base.secuencias.end(); it++){
		wxStringProperty* prop = NULL;
		wxString helpString = wxString::FromUTF8(pDICOMManager->GetDescription((*it).tagName).c_str());

		wxString label;
		if(helpString.size()>0){
			label = wxT("(") + wxString::FromUTF8((*it).tagName.c_str()) + wxT(") ") + helpString;
		}else{
			label = wxT("(") + wxString::FromUTF8((*it).tagName.c_str()) + wxT(") ");
		}
		while(m_pTags->GetProperty(label) != NULL)
			label = label + wxT(" ");
		prop = new wxStringProperty(label,
			wxPG_LABEL,wxEmptyString);

		prop->SetHelpString(wxString::FromUTF8((*it).tagName.c_str()));

		wxPGId pIdSequencia = m_pTags->AppendIn(idPadre,prop);
		pIdSequencia->SetFlag(wxPG_PROP_READONLY);
		//m_pTags->DisableProperty(pIdSequencia);
		//recursion
		int i=0;
		for(GIL::DICOM::TipoJerarquia::ListaJerarquias::iterator it2 = (*it).items.begin(); it2!= (*it).items.end(); it2++, i++) {
			wxPGPropArg pIdItem = m_pTags->AppendIn(pIdSequencia,new wxStringProperty(wxString::Format(wxT("Item %d"),i),wxPG_LABEL,wxEmptyString));
			
			SetTags((*it2), pIdItem, pDICOMManager);
		}
	}
}


//endregion


void GNC::GUI::PanelTags::OnPropertyChanged(wxPropertyGridEvent& /*event*/) {
	/*wxPGProperty* selected= event.GetProperty();
	selected->ClearFlag(wxPG_PROP_INVALID_VALUE);
	//se avisa a la vista para que tenga en cuenta que se ha modificado algún campo DICOM

	GNC::GCS::Eventos::EventoModificacionFichero* pEvt = new GNC::GCS::Eventos::EventoModificacionFichero();
	pEvt->SetVista(m_pVista);
	m_pEntorno->GetControladorEventos()->ProcesarEvento(pEvt);*/

}

void GNC::GUI::PanelTags::OnPropertyChanging(wxPropertyGridEvent& /*event*/) {
	/*wxPGProperty* selected= event.GetProperty();
	selected->ClearFlag(wxPG_PROP_INVALID_VALUE);
	//se avisa a la vista para que tenga en cuenta que se ha modificado algún campo DICOM
	wxString mensaje = wxEmptyString;
	if(selected == m_pEdadPaciente){				
	if(!ValidarLong(event.GetValue().GetString(),0,199)){
	mensaje += wxT("La edad ha de ser un entero entre 0 y 199");
	}
	}
	if(selected == m_pAlturaPaciente){	
	if(!ValidarDouble(event.GetValue().GetString(),0.01f,3.0f)){
	mensaje += wxT("El formato de la altura no es correcto. Ha de ser un numero real entre 0.01 y 3.");
	}
	}
	if(selected == m_pPesoPaciente) {			
	if(!ValidarDouble(event.GetValue().GetString(),0.01f,400.0f)){
	mensaje += wxT("El formato del peso no es correcto. Ha de ser un numero real entre 0.01 y 400.");
	}
	}
	if(selected == m_pHoraEstudio || selected == m_pHoraSerie){
	if(!ValidarHora(event.GetValue())){
	mensaje += wxT("El formato de la hora ha de ser HHMMSS.");
	}
	}
	if(mensaje != wxEmptyString){
	wxMessageBox(mensaje, wxT("Error validar los campos"), wxICON_ERROR);
	event.Veto();
	}*/	
}

==> ginkgocadx_2.12.0.4889.orig.tar.gz: ginkgocadx-2.12.0.4889/src/cadxcore/main/gui/paneltags/paneltags.cpp <==
/*
 *  
 *  $Id: paneltags.cpp 4337 2011-10-26 11:59:44Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#include <api/globals.h>

#include "paneltags.h"

#include <api/icontroladoreventos.h>

#include <api/icontextoestudio.h>
#include <api/dicom/idicommanager.h>

#include <main/controllers/pacscontroller.h>
#include <main/controllers/controladorvistas.h>

#include <eventos/eventosginkgo.h>


GNC::GUI::PanelTags::PanelTags(wxWindow* pPadre) : PanelTagsBase(pPadre)
{
	Freeze();
	//eventos
//	m_pTags->Connect(wxEVT_PG_CHANGED,wxPropertyGridEventHandler(PanelTags::OnPropertyChanged),NULL,this);
//	m_pTags->Connect(wxEVT_PG_CHANGING,wxPropertyGridEventHandler(PanelTags::OnPropertyChanging),NULL,this);

	Thaw();
}

GNC::GUI::PanelTags::~PanelTags()
{
//	m_pTags->Disconnect(wxEVT_PG_CHANGED,wxPropertyGridEventHandler(PanelTags::OnPropertyChanged),NULL,this);
//	m_pTags->Disconnect(wxEVT_PG_CHANGING,wxPropertyGridEventHandler(PanelTags::OnPropertyChanging),NULL,this);
}

bool GNC::GUI::PanelTags::IsVisiblePanelTags()
{
	return IsShown();
}

void GNC::GUI::PanelTags::MostrarOcultarPanelTags()
{
	if (IsShown()) {
		Hide();
	} else {
		//aui bug...
		Show();
	}
}

void GNC::GUI::PanelTags::SetEstudio(GnkPtr<GNC::GCS::IContextoEstudio> pEstudio)
{
	m_pTags->Clear();
	wxPGProperty* metadataGroup =CreatePropertyGroup(_("Metadata"));
	identificationGroup = CreatePropertyGroup(_("Identification information"));
	patientGroup = CreatePropertyGroup(_("Patient information"));
	acquisitionGroup = CreatePropertyGroup(_("Acquisition information"));
	relationshipGroup = CreatePropertyGroup(_("Relationship information"));
	imagePresentationGroup = CreatePropertyGroup(_("Image presentation information"));
	textGroup = CreatePropertyGroup(_("Text"));
	otherGroup = CreatePropertyGroup(_("Other"));

	if(!pEstudio.IsValid() || pEstudio->IndiceFicheroActivo < 0)
	{		
		return;
	}

	GnkPtr<GIL::DICOM::TipoMetaInfo> info = pEstudio->GetMetaInfoDeImagenActiva();
	GnkPtr<GIL::DICOM::TipoJerarquia> pJerarquia = pEstudio->GetTagsImagenDeImagenActiva();
	
	GIL::DICOM::IDICOMManager*	pDICOMManager = GIL::DICOM::PACSController::Instance()->CrearInstanciaDeDICOMManager();
	
	if (info) {
		for(GIL::DICOM::TipoMetaInfo::ListaTags::iterator it = info->tags.begin(); it!= info->tags.end(); it++) {
			wxString helpString = wxString::FromUTF8(pDICOMManager->GetDescription((*it).first).c_str());
			
			wxStringProperty* prop = NULL;
			wxString valor;
			if((*it).second.size()>100) {
				valor = _("Data");
			} else {
				std::string oidname = pDICOMManager->GetOIDName((*it).second);
				if (oidname.size() > 0) {
					valor = wxString::FromUTF8(oidname.c_str()) + wxT("[") + wxString::FromUTF8((*it).second.c_str()) + wxT("]");
				}
				else {
					valor = wxString::FromUTF8((*it).second.c_str());
				}
			}
			
			wxString label;
			if(helpString.size()>0){
				label = wxT("(") + wxString::FromUTF8((*it).first.c_str()) + wxT(") ") + helpString;
			}else{
				label = wxT("(") + wxString::FromUTF8((*it).first.c_str()) + wxT(") ");
			}
			while(m_pTags->GetProperty(label) != NULL)
				label = label + wxT(" ");
			prop = new wxStringProperty(label,
										wxPG_LABEL,valor);
			
			prop->SetHelpString(wxString::FromUTF8((*it).first.c_str()));
						
			m_pTags->AppendIn(metadataGroup, prop);
			prop->SetFlag(wxPG_PROP_READONLY);
			//m_pTags->SetDisableProperty(prop);
		}
	}
	
	SetTags(*pJerarquia, m_pTags->GetRoot(), pDICOMManager);
	GIL::DICOM::PACSController::Instance()->LiberarInstanciaDeDICOMManager(pDICOMManager);
}

void GNC::GUI::PanelTags::SetTags(GIL::DICOM::TipoJerarquia& base, wxPGPropArg idPadre, GIL::DICOM::IDICOMManager* pDICOMManager) 
{	
	for(GIL::DICOM::ListaTags::iterator it = base.tags.begin(); it!= base.tags.end(); it++) {
		wxString helpString = wxString::FromUTF8(pDICOMManager->GetDescription((*it).first).c_str());
		wxStringProperty* prop = NULL;
		wxString valor;
		if((*it).second.size()>100) {
			valor = _("Data");
		} else {
			valor = wxString::FromUTF8((*it).second.c_str());
		}

		wxString label;
		if(helpString.size()>0){
			label = wxT("(") + wxString::FromUTF8((*it).first.c_str()) + wxT(") ") + helpString;
		}else{
			label = wxT("(") + wxString::FromUTF8((*it).first.c_str()) + wxT(") ");
		}
		while(m_pTags->GetProperty(label) != NULL)
			label = label + wxT(" ");
		prop = new wxStringProperty(label,
			wxPG_LABEL,valor);

		prop->SetHelpString(wxString::FromUTF8((*it).first.c_str()));

		InsertTagInGroup(prop, (*it).first, idPadre);
		prop->SetFlag(wxPG_PROP_READONLY);
		//m_pTags->SetDisableProperty(prop);
	}

	for(GIL::DICOM::TipoJerarquia::ListaJerarquias::iterator it = base.secuencias.begin(); it!=base.secuencias.end(); it++){
		wxStringProperty* prop = NULL;
		wxString helpString = wxString::FromUTF8(pDICOMManager->GetDescription((*it).tagName).c_str());

		wxString label;
		if(helpString.size()>0){
			label = wxT("(") + wxString::FromUTF8((*it).tagName.c_str()) + wxT(") ") + helpString;
		}else{
			label = wxT("(") + wxString::FromUTF8((*it).tagName.c_str()) + wxT(") ");
		}
		while(m_pTags->GetProperty(label) != NULL)
			label = label + wxT(" ");
		prop = new wxStringProperty(label,
			wxPG_LABEL,wxEmptyString);

		prop->SetHelpString(wxString::FromUTF8((*it).tagName.c_str()));

		InsertTagInGroup(prop, (*it).tagName, idPadre);
		prop->SetFlag(wxPG_PROP_READONLY);
		//m_pTags->DisableProperty(pIdSequencia);
		//recursion
		int i=0;
		for(GIL::DICOM::TipoJerarquia::ListaJerarquias::iterator it2 = (*it).items.begin(); it2!= (*it).items.end(); it2++, i++) {
			m_pTags->AppendIn(prop,new wxStringProperty(wxString::Format(wxT("Item %d"),i),wxPG_LABEL,wxEmptyString));
			
			SetTags((*it2), prop, pDICOMManager);
		}
	}
}


//endregion


void GNC::GUI::PanelTags::OnPropertyChanged(wxPropertyGridEvent& /*event*/) {
	/*wxPGProperty* selected= event.GetProperty();
	selected->ClearFlag(wxPG_PROP_INVALID_VALUE);
	//se avisa a la vista para que tenga en cuenta que se ha modificado algún campo DICOM

	GNC::GCS::Eventos::EventoModificacionFichero* pEvt = new GNC::GCS::Eventos::EventoModificacionFichero();
	pEvt->SetVista(m_pVista);
	m_pEntorno->GetControladorEventos()->ProcesarEvento(pEvt);*/

}

void GNC::GUI::PanelTags::OnPropertyChanging(wxPropertyGridEvent& /*event*/) {
	/*wxPGProperty* selected= event.GetProperty();
	selected->ClearFlag(wxPG_PROP_INVALID_VALUE);
	//se avisa a la vista para que tenga en cuenta que se ha modificado algún campo DICOM
	wxString mensaje = wxEmptyString;
	if(selected == m_pEdadPaciente){				
	if(!ValidarLong(event.GetValue().GetString(),0,199)){
	mensaje += wxT("La edad ha de ser un entero entre 0 y 199");
	}
	}
	if(selected == m_pAlturaPaciente){	
	if(!ValidarDouble(event.GetValue().GetString(),0.01f,3.0f)){
	mensaje += wxT("El formato de la altura no es correcto. Ha de ser un numero real entre 0.01 y 3.");
	}
	}
	if(selected == m_pPesoPaciente) {			
	if(!ValidarDouble(event.GetValue().GetString(),0.01f,400.0f)){
	mensaje += wxT("El formato del peso no es correcto. Ha de ser un numero real entre 0.01 y 400.");
	}
	}
	if(selected == m_pHoraEstudio || selected == m_pHoraSerie){
	if(!ValidarHora(event.GetValue())){
	mensaje += wxT("El formato de la hora ha de ser HHMMSS.");
	}
	}
	if(mensaje != wxEmptyString){
	wxMessageBox(mensaje, wxT("Error validar los campos"), wxICON_ERROR);
	event.Veto();
	}*/	
}

void GNC::GUI::PanelTags::OnClose(wxCloseEvent &event)
{
	Hide();
	event.Skip(false);
}

wxPGProperty* GNC::GUI::PanelTags::CreatePropertyGroup(const wxString& label)
{
	wxPGProperty* group = new wxPropertyCategory(label, wxPG_LABEL);
	m_pTags->AppendIn(m_pTags->GetRoot(), group);
	return group;
}

void GNC::GUI::PanelTags::InsertTagInGroup(wxPGProperty* prop, const std::string& key, wxPGPropArg idPadre)
{
	if (idPadre.GetPtr() == m_pTags->GetRoot()) {
		//parse group
		unsigned int g = 0xffff;
		{				
			unsigned int e = 0xffff;
			sscanf(key.c_str(), "%x|%x", &g, &e);
		}

		switch (g) {
			case 0x0008:
				m_pTags->AppendIn(identificationGroup, prop);
				break;
			case 0x0010:
				m_pTags->AppendIn(patientGroup, prop);
				break;
			case 0x0018:
				m_pTags->AppendIn(acquisitionGroup, prop);
				break;
			case 0x0020:
				m_pTags->AppendIn(relationshipGroup, prop);
				break;
			case 0x0028:
				m_pTags->AppendIn(imagePresentationGroup, prop);
				break;
			case 0x4000:
				m_pTags->AppendIn(textGroup, prop);
				break;
			default:
				m_pTags->AppendIn(otherGroup, prop);
		}
	} else {
		m_pTags->AppendIn(idPadre, prop);
	}
}
